# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""


class TeamInteger(object):

    """Implementation of the 'team_integer' enum.

    TODO: type enum description here.

    Attributes:
        CODEGEN: TODO: type description here.
        CGAAS: TODO: type description here.
        UX: TODO: type description here.
        QA: TODO: type description here.

    """

    CODEGEN = 1

    CGAAS = 2

    UX = 3

    QA = 4
