# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""


class LanguageEnum(object):

    """Implementation of the 'language_enum' enum.

    TODO: type enum description here.

    Attributes:
        EN: TODO: type description here.
        DZ: TODO: type description here.
        NL: TODO: type description here.

    """

    EN = 'EN'

    DZ = 'DZ'

    NL = 'NL'
