# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""


class Days(object):

    """Implementation of the 'Days' enum.

    A string enum representing days of the week

    Attributes:
        SUNDAY: TODO: type description here.
        MONDAY: TODO: type description here.
        TUESDAY: TODO: type description here.
        WEDNESDAY_: TODO: type description here.
        THURSDAY: TODO: type description here.
        FRI DAY: TODO: type description here.
        SATURDAY: TODO: type description here.

    """

    SUNDAY = 'Sunday'

    MONDAY = 'Monday'

    TUESDAY = 'Tuesday'

    WEDNESDAY_ = 'Wednesday'

    THURSDAY = 'Thursday'

    FRI_DAY = 'Friday'

    SATURDAY = 'Saturday'
