# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""


class Type(object):

    """Implementation of the 'Type' enum.

    TODO: type enum description here.

    Attributes:
        LONG: TODO: type description here.
        NUMBER: TODO: type description here.
        PRECISION: TODO: type description here.
        BOOLEAN: TODO: type description here.
        DATETIME: TODO: type description here.
        DATE: TODO: type description here.
        STRING: TODO: type description here.

    """

    LONG = 'Long'

    NUMBER = 'Number'

    PRECISION = 'Precision'

    BOOLEAN = 'Boolean'

    DATETIME = 'DateTime'

    DATE = 'Date'

    STRING = 'String'
