# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""


class SuiteCode(object):

    """Implementation of the 'SuiteCode' enum.

    A integer based enum representing a Suite in a game of cards

    Attributes:
        HEARTS: TODO: type description here.
        SPADES: TODO: type description here.
        CLUBS: TODO: type description here.
        DIAMONDS: TODO: type description here.

    """

    HEARTS = 1

    SPADES = 2

    CLUBS = 3

    DIAMONDS = 4
