# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""


class ParamFormat(object):

    """Implementation of the 'ParamFormat' enum.

    TODO: type enum description here.

    Attributes:
        TEMPLATE: TODO: type description here.
        FORM: TODO: type description here.
        BODY: TODO: type description here.
        HEADER: TODO: type description here.
        QUERY: TODO: type description here.

    """

    TEMPLATE = 'Template'

    FORM = 'Form'

    BODY = 'Body'

    HEADER = 'Header'

    QUERY = 'Query'
