# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""


class Team(object):

    """Implementation of the 'team' enum.

    TODO: type enum description here.

    Attributes:
        CODEGEN: TODO: type description here.
        CGAAS: TODO: type description here.
        UX: TODO: type description here.
        QA: TODO: type description here.

    """

    CODEGEN = 'codegen'

    CGAAS = 'cgaas'

    UX = 'ux'

    QA = 'qa'
